"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const inversify_1 = require("inversify");
const Server_1 = require("./api/Server");
const AppConfig_1 = require("./model/AppConfig");
/**
 * Application base class which combines the `Server`, `Container`(`InversifyJS`)
 * and `AppConfig` classes to create a decorator driven API with typescript
 * middleware and dependency injection. It uses the `lambda-api` package as the
 * underlying HTTP API framework.
 *
 * AWS Lambda requests are handled by the `run` method, which will return a response
 * compatible with either API Gateway or an ALB.
 *
 * Extending this class will allow creating an app implementation for runtimes,
 * AWS Lambda or local web server for example.
 */
class ApiApp {
    get middlewareRegistry() {
        return this.apiServer.middlewareRegistry;
    }
    /**
     * Create a new app.
     *
     * @param appConfig (Optional) Application config to pass to `lambda-api`.
     * @param appContainer (Optional) `InversifyJS` IOC `Container` instance which can build controllers and error interceptors.
     */
    constructor(appConfig, appContainer) {
        this.appContainer = appContainer || new inversify_1.Container({ autoBindInjectable: true });
        this.apiServer = new Server_1.Server(appConfig || new AppConfig_1.AppConfig());
    }
    /**
     * Configure the `InversifyJS` IOC `Container` instance.
     *
     * @param configureBlock Function that takes a `Container` instance as a parameter.
     */
    configureApp(configureBlock) {
        configureBlock(this.appContainer);
    }
    /**
     * Configure the `API` instance from the `lambda-api` package.
     *
     * @param handler Function that takes an `API` instance as a parameter.
     */
    configureApi(configureBlock) {
        this.apiServer.configure(configureBlock);
    }
    /**
     * Convience method for invoking the `apiServer` instance `discoverAndBuildRoutes`
     * method.
     *
     * @param controllersPath Path to the directory containing controller `js` files.
     */
    async initialiseControllers(controllersPath) {
        await this.apiServer.discoverAndBuildRoutes(controllersPath, this.appContainer);
    }
}
exports.ApiApp = ApiApp;
//# sourceMappingURL=ApiApp.js.map